local api = require("gemini.api")
local M = {}

-- Cache for completion items
local completion_cache = {}

-- Helper function to create completion items from Gemini response
local function parse_completion_response(response)
    -- Split response into lines and filter out empty ones
    local lines = vim.split(response, "\n")
    local items = {}
    
    for _, line in ipairs(lines) do
        if line and line:match("^%s*[^%s]") then -- Skip empty lines
            table.insert(items, {
                word = line,  -- Changed from label to word
                kind = vim.lsp.protocol.CompletionItemKind.Text,
                menu = "[Gemini]",  -- Added menu indicator
                info = line,  -- Added info
            })
        end
    end
    
    return items
end

function M.get_completion(params, callback)
    vim.notify("Gemini completion triggered", vim.log.levels.INFO)
    local cursor = vim.api.nvim_win_get_cursor(0)
    local line = cursor[1]
    local col = cursor[2]
    
    -- Get current buffer content for context
    local lines = vim.api.nvim_buf_get_lines(0, math.max(0, line - 10), line, false)
    local prefix = table.concat(lines, "\n")
    
    -- Get current line up to cursor
    local current_line = vim.api.nvim_get_current_line()
    local before_cursor = string.sub(current_line, 1, col)
    
    -- Construct prompt for Gemini
    local prompt = string.format(
        "Complete this code. Only provide the completion, no explanation:\n%s\n%s",
        prefix,
        before_cursor
    )
    
    vim.notify("Sending completion request to Gemini", vim.log.levels.INFO)
    
    -- Get completion from Gemini
    api.get_response(prompt, nil, function(response, error)
        if error then
            vim.notify("Completion error: " .. error, vim.log.levels.ERROR)
            vim.schedule(function()
                callback({})
            end)
            return
        end
        
        vim.notify("Received completion response", vim.log.levels.INFO)
        local items = parse_completion_response(response)
        vim.schedule(function()
            callback(items)
        end)
    end)
end

return M